@@ -1,10 +1,10 @@
-__version__ = "0.3.6"
+__version__ = "0.3.7"
 __git_commiter_name__ = "Guy Rozendorn"
 __git_commiter_email__ = "guy@rzn.co.il"
-__git_branch__ = '(detached from v0.3.6)'
+__git_branch__ = '(detached from v0.3.7)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'a285b1c7fe0f94e1891df349d155cae03d01c66d'
-__git_head_subject__ = 'updated project files from skeleton'
+__git_head_hash__ = 'c0b147d40573079f51ebf90b4d80451d2c0d5730'
+__git_head_subject__ = 'TRIVIAL fixing the nose plugin entry point'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
